# Integration

## Sigma notation

if $m$ and $n$ are integers with $m \leq n$, and if $f$ is a function defined as $f: \{m,m+1,...,n\} \to \mathbb{R}$, the symbol $\sum_{i=m}^{n} f(i)$ represents the sum of the values of $f$ at those integers:

$$
\sum_{i=m}^{n} f(i) = f(m) + f(m+1) + f(m+2) + ... + f(n).
$$

The explicit sum appearing on the right side of this equation is the **expansion** of the sum represented in sigma notation on the left side.

## Partitions

Let $P$ be a finite set of points arranged in order between $a$ and $b$ on the real line

$$
P = {x_0, x_1, ... , x_{n-1}, x_n},
$$

where $a = x_0 < x_1 < ... < x_{n-1} < x_n = b$. Such a set $P$ is called a **partition** of $[a,b]$; it divides $[a,b]$ into $n$ subintervals of which the *i*th is $[x_{i-1},x_i]. The length of the *i*th subinterval of $P$ is

$$
\Delta x_i = x_i - x_{i-1} \quad \mathrm{for} \space 1 \leq i \leq n,
$$

Then, the **norm** of the partition $P$ is defined as

$$
\parallel P \parallel = \max_{1 \leq i \leq n} \Delta x_i
$$

If the function $f$ is continuous on the interval $[a,b]$, it is continuous on each subinterval $[x_{i-1},x_i]$, and has a maximum $u_i$ and minimum $l_i$ on each subinterval by the [Extreme value theorem](continuity.md/#the-extreme-value-theorem) such that

$$
f(l_i) \leq f(x) \leq f(u_i) \quad \forall x \in [x_{i-1},x_i]/
$$

## Upper and lower Riemann sums

The **lower Riemann sum**, $L(f,P)$, and the **upper Riemann sum**, $U(f,P)$, for the function $f$ amd the partition $P$ are defined by:

$$
\begin{array}{ll}
L(f,P) &= f(l_1)\Delta x_1 + f(l_2)\Delta x_2 + ... + f(l_n)\Delta x_n \\
       &= \sum_{i=1}^n f(l_i)\Delta x_i, \\
U(f,P) &= f(u_1)\Delta x_1 + f(u_2)\Delta x_2 + ... + f(u_n)\Delta x_n \\
       &= \sum_{i=1}^n f(u_i)\Delta x_i.
\end{array}
$$

**Theorem:** for any partitions $P$, $Q$ on $[a,b]$ all lower Riemann sums are smaller than or equal to any upper Riemann sums:

$$
L(f,P) \leq U(f,Q).
$$

**Proof:** let $P$, $Q$ be partitions on $[a,b]$, suppose $L(f,P) \leq U(f,Q)$, define $R = P \cup Q$, $R$ is a refinement of $P$, $Q$. Then,

$$
L(f,P) \leq L(f,R) \leq U(f,R) \leq U(f,Q).
$$

## The definite integral

Suppose there exists exactly one number $I \in \mathbb{R}$ such that for every partition $P$ of $[a,b]$:

$$
L(f,P) \leq I \leq U(f,P).
$$

Then the function $f$ is integrable on $[a,b]$ and $I$ is called the definite integral

$$
I = \int_a^b f(x) dx.
$$

**Theorem:** suppose that a function $f$ is bounded on the interval $[a,b]$, then $f$ is integrable on $[a,b]$ if and only if $\forall \varepsilon > 0$ there exists a partition $P$ of $[a,b]$ such that

$$
U(f,P) - L(f,P) < \varepsilon.
$$

**Proof:** let $a,b \in \mathbb{R}$, $\forall \varepsilon > 0$ there is $|a-b| < \varepsilon$ then $a=b$.

**Theorem:** if $f$ is continuous on the interval $[a,b]$, then $f$ is integrable on $[a,b]$.

**Proof:** is missing...

### Properties

* If $a \leq b$ and $f(x) \leq g(x) \space \forall x \in [a,b]$:

$$
\int_a^b f(x)dx \leq \int_a^b g(x)dx.
$$

**Proof:** is missing...

* The **triangle inequality** for sums extends to definite integrals. If $a \leq b$, then

$$
|\int_a^b f(x)dx| \leq \int_a^b |f(x)|dx.
$$

**Proof:** is missing...

* Integral of an odd function $f(-x) = -f(x)$:

$$
\int_{-a}^a f(x)dx = 0.
$$

**Proof:** is missing...

* Integral of an even function $f(-x) = f(x)$:

$$
\int_{-a}^a f(x)dx = 2\int_0^a f(x)dx.
$$

**Proof:** is missing...

## The Mean-value theorem for integrals

If the function $f$ is continuous on $[a,b]$ then there exists a point $c$ in $[a,b]$ such that

$$
\int_a^b f(x)dx = (b-a)f(c)
$$

**Proof:** $\forall x \in [a,b]$,

let $m \leq f(x) \leq M$,

$$m(b-a)=\int_a^b mdx \leq \int_a^b f(x)dx \leq \int_a^b Mdx = M(b-a),$$

$$m \leq \frac{1}{b-a} \int_a^b f(x)dx \leq M,$$

According to [the intermediate value theorem](continuity.md/#the-intermediate-value-theorem) there exists a $c \in [a,b]$ such that

$$\frac{1}{b-a} \int_a^b f(x)dx = f(c)$$

## Piecewise continuous functions

Let $c_0 < c_1 < ... < c_n$ be a finite set of points on the real line. A function $f$ defined on $[c_0,c_n]$ except possibly at some of the points $c_i$, $(0 \leq i \leq n)$, is called piecewise continuous on that interval if for each $i$ $(1 \leq i \leq b)$ there exists a function $F_i$ continuous on the *closed* interval $[c_{i-1},c_i]$ such that

$$
f(x) = F_i(x).
$$

In this case, te integral of $f$ from $c_0$ to $c_n$ is defined to be

$$
\int_{c_0}^{c_n} f(x)dx = \sum_{i=1}^n \int_{c_i-1}^{c_i} F_i(x)dx.
$$

## The fundamental theorem of calculus

Suppose that the function $f$ is continuous on an interval $I$ containing the point $a$. 

**Part I.** Let the function $F$ be defined on $I$ by

$$
F(x) = \int_a^x f(t)dt.
$$

Then $F$ is differentiable on $I$, and $F'(x) = f(x)$ there. Thus, $F$ is an antiderivative of $f$ on $I$:

$$
\frac{d}{dx} \int_a^x f(t)dt = f(x).
$$

**Part II.** If $G(x)$ is *any* antiderivative of $f(x)$ on $I$, so that $G'(x) = f(x)$ on $I$, then for any $b$ in $I$ there is

$$
\int_a^b f(x)dx = G(b) - G(a).
$$

**Proof:** using the definitions of the derivative

$$
\begin{array}{ll}
F'(x) &= \lim_{h \to 0} \frac{F(x+h)-F(x)}{h}, \\
      &= \lim_{h \to 0} \frac{1}{h}(\int_a^{x+h} f(t)dt - \int_a^x f(t)dt), \\
      &= \lim_{h \to 0} \frac{1}{h} \int_x^{x+h} f(t)dt, \\
      &= \lim_{h \to 0} hf(c) \quad \mathrm{for \space some} \space c \in [x,x+h], \\
      &= \lim_{c \to x} f(c), \\
      &= f(x).
\end{array}
$$